==> tencentcloud-sdk-java-3.1.72-sources.jar: com/tencentcloudapi/cat/v20180409/models/AlarmTopic.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cat.v20180409.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class AlarmTopic extends AbstractModel{

    /**
    * 主题的ID
    */
    @SerializedName("TopicId")
    @Expose
    private String TopicId;

    /**
    * 主题的名称
    */
    @SerializedName("TopicName")
    @Expose
    private String TopicName;

    /**
     * Get 主题的ID 
     * @return TopicId 主题的ID
     */
    public String getTopicId() {
        return this.TopicId;
    }

    /**
     * Set 主题的ID
     * @param TopicId 主题的ID
     */
    public void setTopicId(String TopicId) {
        this.TopicId = TopicId;
    }

    /**
     * Get 主题的名称 
     * @return TopicName 主题的名称
     */
    public String getTopicName() {
        return this.TopicName;
    }

    /**
     * Set 主题的名称
     * @param TopicName 主题的名称
     */
    public void setTopicName(String TopicName) {
        this.TopicName = TopicName;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TopicId", this.TopicId);
        this.setParamSimple(map, prefix + "TopicName", this.TopicName);

    }
}

==> tencentcloud-sdk-java-3.1.433-sources.jar: com/tencentcloudapi/cat/v20180409/models/AlarmTopic.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cat.v20180409.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class AlarmTopic extends AbstractModel{

    /**
    * 主题的ID
    */
    @SerializedName("TopicId")
    @Expose
    private String TopicId;

    /**
    * 主题的名称
    */
    @SerializedName("TopicName")
    @Expose
    private String TopicName;

    /**
     * Get 主题的ID 
     * @return TopicId 主题的ID
     */
    public String getTopicId() {
        return this.TopicId;
    }

    /**
     * Set 主题的ID
     * @param TopicId 主题的ID
     */
    public void setTopicId(String TopicId) {
        this.TopicId = TopicId;
    }

    /**
     * Get 主题的名称 
     * @return TopicName 主题的名称
     */
    public String getTopicName() {
        return this.TopicName;
    }

    /**
     * Set 主题的名称
     * @param TopicName 主题的名称
     */
    public void setTopicName(String TopicName) {
        this.TopicName = TopicName;
    }

    public AlarmTopic() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public AlarmTopic(AlarmTopic source) {
        if (source.TopicId != null) {
            this.TopicId = new String(source.TopicId);
        }
        if (source.TopicName != null) {
            this.TopicName = new String(source.TopicName);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TopicId", this.TopicId);
        this.setParamSimple(map, prefix + "TopicName", this.TopicName);

    }
}
